==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/http/log/AbstractErrorLog.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.http.log;

import com.caucho.log.Log;
import com.caucho.vfs.WriteStream;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.logging.Logger;

/**
 * Represents an log of every error log request to the server.
 */
abstract public class AbstractErrorLog {
  protected static final Logger log = Log.open(AbstractErrorLog.class);

  protected WriteStream logStream;

  /**
   * Returns the access-log's path.
   */
  public WriteStream getLogStream()
  {
    return logStream;
  }

  /**
   * Sets the access-log's path.
   */
  public void setLogStream(WriteStream os)
  {
    this.logStream = os;
  }

  /**
   * Initialize the log.
   */
  public void init()
    throws ServletException, IOException
  {
  }

  /**
   * Logs an error.
   *
   * @param message the error message
   * @param request the servlet request
   * @param response the servlet response
   * @param application the servlet context
   */
  public abstract void log(String message,
                           HttpServletRequest request,
                           HttpServletResponse response,
                           ServletContext application)
    throws IOException;

  /**
   * Logs an error.
   *
   * @param message the error message
   * @param exception the thrown exception
   * @param request the servlet request
   * @param response the servlet response
   * @param application the servlet context
   */
  public abstract void log(String message,
                           Throwable exception,
                           HttpServletRequest request,
                           HttpServletResponse response,
                           ServletContext application)
    throws IOException;

  /**
   * Cleanup the log.
   */
  public void destroy()
    throws IOException
  {
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/http/log/AbstractErrorLog.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.http.log;

import com.caucho.vfs.WriteStream;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.logging.Logger;

/**
 * Represents an log of every error log request to the server.
 */
abstract public class AbstractErrorLog {
  protected static final Logger log
    = Logger.getLogger(AbstractErrorLog.class.getName());

  protected WriteStream logStream;

  /**
   * Returns the access-log's path.
   */
  public WriteStream getLogStream()
  {
    return logStream;
  }

  /**
   * Sets the access-log's path.
   */
  public void setLogStream(WriteStream os)
  {
    this.logStream = os;
  }

  /**
   * Initialize the log.
   */
  public void init()
    throws ServletException, IOException
  {
  }

  /**
   * Logs an error.
   *
   * @param message the error message
   * @param request the servlet request
   * @param response the servlet response
   * @param application the servlet context
   */
  public abstract void log(String message,
                           HttpServletRequest request,
                           HttpServletResponse response,
                           ServletContext application)
    throws IOException;

  /**
   * Logs an error.
   *
   * @param message the error message
   * @param exception the thrown exception
   * @param request the servlet request
   * @param response the servlet response
   * @param application the servlet context
   */
  public abstract void log(String message,
                           Throwable exception,
                           HttpServletRequest request,
                           HttpServletResponse response,
                           ServletContext application)
    throws IOException;

  /**
   * Cleanup the log.
   */
  public void destroy()
    throws IOException
  {
  }
}
